@@ -1,21 +1,25 @@
-from collections import defaultdict
 from collections.abc import Callable, Iterable
 from functools import partial
 from numbers import Number
 
-import ipywidgets as widgets
-import matplotlib.widgets as mwidgets
 import numpy as np
-from IPython.display import display as ipy_display
-from matplotlib import __version__ as mpl_version
+from matplotlib.cbook.deprecation import deprecated
 from matplotlib.collections import PatchCollection
 from matplotlib.colors import to_rgba_array
 from matplotlib.patches import Rectangle
-from matplotlib.pyplot import axes, sca
-from packaging import version
+from matplotlib.pyplot import sca
 
-from .helpers import broadcast_many, notebook_backend, update_datalim_from_bbox, callable_else_value
-from .utils import figure, ioff
+from .helpers import (
+    broadcast_many,
+    callable_else_value,
+    create_slider_format_dict,
+    gogogo_display,
+    gogogo_figure,
+    kwargs_to_ipywidgets,
+    kwargs_to_mpl_widgets,
+    notebook_backend,
+    update_datalim_from_bbox,
+)
 
 # functions that are methods
 __all__ = [
@@ -27,238 +31,9 @@ __all__ = [
 ]
 
 
-def _kwargs_to_widget(kwargs, params, update, slider_format_strings):
-    """
-    this will break if you pass a matplotlib slider. I suppose it could support mixed types of sliders
-    but that doesn't really seem worthwhile?
-    """
-    labels = []
-    sliders = []
-    controls = []
-    for key, val in kwargs.items():
-        if isinstance(val, set):
-            if len(val) == 1:
-                val = val.pop()
-                if isinstance(val, tuple):
-                    # want the categories to be ordered
-                    pass
-                else:
-                    # fixed parameter
-                    params[key] = val
-            else:
-                val = list(val)
-
-            # categorical
-            if len(val) <= 3:
-                selector = widgets.RadioButtons(options=val)
-            else:
-                selector = widgets.Select(options=val)
-            params[key] = val[0]
-            controls.append(selector)
-            selector.observe(partial(update, key=key, label=None), names=["value"])
-        elif isinstance(val, widgets.Widget) or isinstance(val, widgets.fixed):
-            if not hasattr(val, "value"):
-                raise TypeError(
-                    "widgets passed as parameters must have the `value` trait."
-                    "But the widget passed for {key} does not have a `.value` attribute"
-                )
-            if isinstance(val, widgets.fixed):
-                params[key] = val.value
-            else:
-                params[key] = val.value
-                controls.append(val)
-                val.observe(partial(update, key=key, label=None), names=["value"])
-        else:
-            if isinstance(val, tuple) and len(val) in [2, 3]:
-                # treat as an argument to linspace
-                # idk if it's acceptable to overwrite kwargs like this
-                # but I think at this point kwargs is just a dict like any other
-                val = np.linspace(*val)
-                kwargs[key] = val
-            val = np.atleast_1d(val)
-            if val.ndim > 1:
-                raise ValueError(f"{key} is {val.ndim}D but can only be 1D or a scalar")
-            if len(val) == 1:
-                # don't need to create a slider
-                params[key] = val
-            else:
-                params[key] = val[0]
-                labels.append(widgets.Label(value=slider_format_strings[key].format(val[0])))
-                sliders.append(
-                    widgets.IntSlider(min=0, max=val.size - 1, readout=False, description=key)
-                )
-                controls.append(widgets.HBox([sliders[-1], labels[-1]]))
-                sliders[-1].observe(partial(update, key=key, label=labels[-1]), names=["value"])
-    return sliders, labels, controls
-
-
-def _extract_num_options(val):
-    """
-    convert a categorical to a number of options
-    """
-    if len(val) == 1:
-        for v in val:
-            if isinstance(v, tuple):
-                # this looks nightmarish...
-                # but i think it should always work
-                # should also check if the tuple has length one here.
-                # that will only be an issue if a trailing comma was used to make the tuple ('beep',)
-                # but not ('beep') - the latter is not actually a tuple
-                return len(v)
-            else:
-                return 0
-    else:
-        return len(val)
-
-
-def _changeify(val, key, update):
-    """
-    make matplotlib update functions return a dict with key 'new'.
-    Do this for compatibility with ipywidgets
-    """
-    update({"new": val}, key, None)
-
-
-# this is a bunch of hacky nonsense
-# making it involved me holding a ruler up to my monitor
-# if you have a better solution I would love to hear about it :)
-# - Ian 2020-08-22
-def _kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings):
-    n_opts = 0
-    n_radio = 0
-    n_sliders = 0
-    for key, val in kwargs.items():
-        if isinstance(val, set):
-            new_opts = _extract_num_options(val)
-            if new_opts > 0:
-                n_radio += 1
-                n_opts += new_opts
-        elif (
-            not isinstance(val, mwidgets.AxesWidget)
-            and not isinstance(val, widgets.fixed)
-            and isinstance(val, Iterable)
-            and len(val) > 1
-        ):
-            n_sliders += 1
-
-    # These are roughly the sizes used in the matplotlib widget tutorial
-    # https://matplotlib.org/3.2.2/gallery/widgets/slider_demo.html#sphx-glr-gallery-widgets-slider-demo-py
-    slider_in = 0.15
-    radio_in = 0.6 / 3
-    widget_gap_in = 0.1
-
-    widget_inches = (
-        n_sliders * slider_in + n_opts * radio_in + widget_gap_in * (n_sliders + n_radio + 1) + 0.5
-    )  # half an inch for margin
-    fig = None
-    if not all(map(lambda x: isinstance(x, mwidgets.AxesWidget), kwargs.values())):
-        # if the only kwargs are existing matplotlib widgets don't make a new figure
-        with ioff:
-            fig = figure()
-        size = fig.get_size_inches()
-        fig_h = widget_inches
-        fig.set_size_inches(size[0], widget_inches)
-        slider_height = slider_in / fig_h
-        radio_height = radio_in / fig_h
-        # radio
-        gap_height = widget_gap_in / fig_h
-    widget_y = 0.05
-    slider_ax = []
-    sliders = []
-    radio_ax = []
-    radio_buttons = []
-    cbs = []
-    for key, val in kwargs.items():
-        if isinstance(val, set):
-            if len(val) == 1:
-                val = val.pop()
-                if isinstance(val, tuple):
-                    pass
-                else:
-                    params[key] = val
-                    continue
-            else:
-                val = list(val)
-
-            n = len(val)
-            longest_len = max(list(map(lambda x: len(list(x)), map(str, val))))
-            # should probably use something based on fontsize rather that .015
-            width = max(0.15, 0.015 * longest_len)
-            radio_ax.append(axes([0.2, 0.9 - widget_y - radio_height * n, width, radio_height * n]))
-            widget_y += radio_height * n + gap_height
-            radio_buttons.append(mwidgets.RadioButtons(radio_ax[-1], val, active=0))
-            cbs.append(radio_buttons[-1].on_clicked(partial(_changeify, key=key, update=update)))
-            params[key] = val[0]
-        elif isinstance(val, mwidgets.RadioButtons):
-            val.on_clicked(partial(_changeify, key=key, update=update))
-            params[key] = val.val
-        elif isinstance(val, mwidgets.Slider):
-            val.on_changed(partial(_changeify, key=key, update=update))
-            params[key] = val.val
-        else:
-            if isinstance(val, tuple):
-                if len(val) == 2:
-                    min_ = val[0]
-                    max_ = val[1]
-                elif len(val) == 3:
-                    # should warn that that doesn't make sense with matplotlib sliders
-                    min_ = val[0]
-                    max_ = val[1]
-            else:
-                val = np.atleast_1d(val)
-                if val.ndim > 1:
-                    raise ValueError(f"{key} is {val.ndim}D but can only be 1D or a scalar")
-                if len(val) == 1:
-                    # don't need to create a slider
-                    params[key] = val[0]
-                    continue
-                else:
-                    # list or numpy array
-                    # should warn here as well
-                    min_ = np.min(val)
-                    max_ = np.max(val)
-
-            slider_ax.append(axes([0.2, 0.9 - widget_y - gap_height, 0.65, slider_height]))
-            sliders.append(
-                mwidgets.Slider(
-                    slider_ax[-1],
-                    key,
-                    min_,
-                    max_,
-                    valinit=min_,
-                    valfmt=slider_format_strings[key],
-                )
-            )
-            cbs.append(sliders[-1].on_changed(partial(_changeify, key=key, update=update)))
-            widget_y += slider_height + gap_height
-            params[key] = min_
-    controls = [fig, radio_ax, radio_buttons, slider_ax, sliders]
-    return controls
-
-
-def _create_slider_format_dict(slider_format_string, use_ipywidgets):
-    # mpl sliders for verison 3.3 and onwards support None as an argument for valfmt
-    mpl_gr_33 = version.parse(mpl_version) >= version.parse("3.3")
-    if isinstance(slider_format_string, str):
-        slider_format_strings = defaultdict(lambda: slider_format_string)
-    elif isinstance(slider_format_string, dict) or slider_format_string is None:
-        if use_ipywidgets:
-            slider_format_strings = defaultdict(lambda: "{:.2f}")
-        elif mpl_gr_33:
-            slider_format_strings = defaultdict(lambda: None)
-        else:
-            slider_format_strings = defaultdict(lambda: "%1.2f")
-
-        if slider_format_string is not None:
-            for key, val in slider_format_string.items():
-                slider_format_strings[key] = val
-    else:
-        raise ValueError(
-            f"slider_format_string must be a dict or a string but it is a {type(slider_format_string)}"
-        )
-    return slider_format_strings
-
-
+@deprecated(
+    "0.6.1", alternative="interactive_plot with the ax argument", name="heck", removal="0.7.0"
+)
 def interactive_plot_factory(
     ax,
     f,
@@ -269,6 +44,8 @@ def interactive_plot_factory(
     plot_kwargs=None,
     title=None,
     use_ipywidgets=None,
+    play_buttons=False,
+    play_button_pos="right",
     **kwargs,
 ):
     """
@@ -281,13 +58,127 @@ def interactive_plot_factory(
     use_ipywidgets : None or boolean, optional
         If None will attempt to infer whether to use ipywidgets based on the backend. Use
         True or False to ensure ipywidgets is or is not used.
+    play_buttons : bool or dict, optional
+        Whether to attach an ipywidgets.Play widget to any sliders that get created.
+        If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
+        want to attach play buttons too.
+    play_button_pos : str, or dict, or list(str)
+        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
     """
-    if use_ipywidgets is None:
-        use_ipywidgets = notebook_backend()
+    return interactive_plot(
+        f,
+        x=x,
+        xlim=xlim,
+        ylim=ylim,
+        slider_format_string=slider_format_string,
+        plot_kwargs=plot_kwargs,
+        title=title,
+        ax=ax,
+        display=False,
+        force_ipywidgets=use_ipywidgets,
+        play_buttons=play_buttons,
+        play_button_pos=play_button_pos,
+        **kwargs,
+    )[-1].children
+
+
+def interactive_plot(
+    f,
+    x=None,
+    xlim="stretch",
+    ylim="stretch",
+    slider_format_string=None,
+    plot_kwargs=None,
+    title=None,
+    figsize=None,
+    ax=None,
+    display=True,
+    force_ipywidgets=False,
+    play_buttons=False,
+    play_button_pos="right",
+    **kwargs,
+):
+    """
+    Control a plot using widgets
+
+    parameters
+    ----------
+    f : function or list(functions)
+        The function(s) to plot. Each function should return either the y values, or
+        a list of both the x and y arrays to plot [x, y]
+    x : arraylike or None
+        x values a which to evaluate the function. If None the function(s) f should
+        return a list of [x, y]
+    xlim : string or tuple of floats, optional
+        If a tuple it will be passed to ax.set_xlim. Other options are:
+        'auto': rescale the x axis for every redraw
+        'stretch': only ever expand the xlims.
+    ylim : string or tuple of floats, optional
+        If a tuple it will be passed to ax.set_ylim. Other options are same
+        as xlim
+    slider_format_string : None, string, or dict
+        If None a default value of decimal points will be used. For ipywidgets this uses the new f-string formatting
+        For matplotlib widgets you need to use `%` style formatting. A string will be used as the default
+        format for all values. A dictionary will allow assigning different formats to different sliders.
+        note: For matplotlib >= 3.3 a value of None for slider_format_string will use the matplotlib ScalarFormatter
+        object for matplotlib slider values.
+    plot_kwargs : None, dict, or iterable of dicts
+        Keyword arguments to pass to plot. If using multiple f's then plot_kwargs must be either
+        None or be iterable.
+    title : None or string
+        If a string then you can have it update automatically using string formatting of the names
+        of the parameters. i.e. to include the current value of tau: title='the value of tau is: {tau:.2f}'
+    figsize : tuple or scalar
+        If tuple it will be used as the matplotlib figsize. If a number
+        then it will be used to scale the current rcParams figsize
+    ax : matplotlib axis, optional
+        If None a new figure and axis will be created
+    display : boolean
+        If True then the output and controls will be automatically displayed
+    force_ipywidgets : boolean
+        If True ipywidgets will always be used, even if not using the ipympl backend.
+        If False the function will try to detect if it is ok to use ipywidgets
+        If ipywidgets are not used the function will fall back on matplotlib widgets
+    play_buttons : bool or dict, optional
+        Whether to attach an ipywidgets.Play widget to any sliders that get created.
+        If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
+        want to attach play buttons too.
+    play_button_pos : str, or dict, or list(str)
+        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
+
+    returns
+    -------
+    fig : matplotlib figure
+    ax : matplotlib axis
+    controls : list of widgets
+
+    Examples
+    --------
+
+    With numpy arrays::
+
+        x = np.linspace(0,2*np.pi)
+        tau = np.linspace(0, np.pi)
+        def f(x, tau):
+            return np.sin(x+tau)
+        interactive_plot(f, x=x, tau=tau)
+
+    with tuples::
+
+        x = np.linspace(0,2*np.pi)
+        def f(x, tau):
+            return np.sin(x+tau)
+        interactive_plot(f, x=x, tau=(0, np.pi, 1000))
+
+    """
+
+    ipympl = notebook_backend()
+    use_ipywidgets = ipympl or force_ipywidgets
+    fig, ax = gogogo_figure(ipympl, figsize=figsize, ax=ax)
     params = {}
     funcs = np.atleast_1d(f)
 
-    slider_format_strings = _create_slider_format_dict(slider_format_string, use_ipywidgets)
+    slider_format_strings = create_slider_format_dict(slider_format_string, use_ipywidgets)
 
     def update(change, key, label):
         if label:
@@ -334,11 +225,11 @@ def interactive_plot_factory(
 
     fig = ax.get_figure()
     if use_ipywidgets:
-        sliders, slabels, controls = _kwargs_to_widget(
-            kwargs, params, update, slider_format_strings
+        sliders, slabels, controls, play_buttons = kwargs_to_ipywidgets(
+            kwargs, params, update, slider_format_strings, play_buttons, play_button_pos
         )
     else:
-        controls = _kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
+        controls = kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
         sca(ax)
 
     indexed_x = False
@@ -391,139 +282,8 @@ def interactive_plot_factory(
     # make sure the home button will work
     if hasattr(fig.canvas, "toolbar") and fig.canvas.toolbar is not None:
         fig.canvas.toolbar.push_current()
-    return controls
 
-
-def _gogogo_figure(ipympl, figsize, ax=None):
-    """
-    gogogo the greatest function name of all
-    """
-    if ax is None:
-        if ipympl:
-            with ioff:
-                fig = figure(figsize=figsize)
-                ax = fig.gca()
-        else:
-            fig = figure(figsize=figsize)
-            ax = fig.gca()
-        return fig, ax
-    else:
-        return ax.get_figure(), ax
-
-
-def _gogogo_display(ipympl, use_ipywidgets, display, controls, fig):
-    if use_ipywidgets:
-        controls = widgets.VBox(controls)
-        if display:
-            if ipympl:
-                ipy_display(widgets.VBox([controls, fig.canvas]))
-            else:
-                # for the case of using %matplotlib qt
-                # but also want ipywidgets sliders
-                # ie with force_ipywidgets = True
-                ipy_display(controls)
-                fig.show()
-    else:
-        if display:
-            fig.show()
-            controls[0].show()
-
-
-def interactive_plot(
-    f,
-    x=None,
-    xlim="stretch",
-    ylim="stretch",
-    slider_format_string=None,
-    plot_kwargs=None,
-    title=None,
-    figsize=None,
-    display=True,
-    force_ipywidgets=False,
-    **kwargs,
-):
-    """
-    Control a plot using widgets
-
-    parameters
-    ----------
-    f : function or list(functions)
-        The function(s) to plot. Each function should return either the y values, or
-        a list of both the x and y arrays to plot [x, y]
-    x : arraylike or None
-        x values a which to evaluate the function. If None the function(s) f should
-        return a list of [x, y]
-    xlim : string or tuple of floats, optional
-        If a tuple it will be passed to ax.set_xlim. Other options are:
-        'auto': rescale the x axis for every redraw
-        'stretch': only ever expand the xlims.
-    ylim : string or tuple of floats, optional
-        If a tuple it will be passed to ax.set_ylim. Other options are same
-        as xlim
-    slider_format_string : None, string, or dict
-        If None a default value of decimal points will be used. For ipywidgets this uses the new f-string formatting
-        For matplotlib widgets you need to use `%` style formatting. A string will be used as the default
-        format for all values. A dictionary will allow assigning different formats to different sliders.
-        note: For matplotlib >= 3.3 a value of None for slider_format_string will use the matplotlib ScalarFormatter
-        object for matplotlib slider values.
-    plot_kwargs : None, dict, or iterable of dicts
-        Keyword arguments to pass to plot. If using multiple f's then plot_kwargs must be either
-        None or be iterable.
-    title : None or string
-        If a string then you can have it update automatically using string formatting of the names
-        of the parameters. i.e. to include the current value of tau: title='the value of tau is: {tau:.2f}'
-    figsize : tuple or scalar
-        If tuple it will be used as the matplotlib figsize. If a number
-        then it will be used to scale the current rcParams figsize
-    display : boolean
-        If True then the output and controls will be automatically displayed
-    force_ipywidgets : boolean
-        If True ipywidgets will always be used, even if not using the ipympl backend.
-        If False the function will try to detect if it is ok to use ipywidgets
-        If ipywidgets are not used the function will fall back on matplotlib widgets
-
-    returns
-    -------
-    fig : matplotlib figure
-    ax : matplotlib axis
-    controls : list of widgets
-
-    Examples
-    --------
-
-    With numpy arrays::
-
-        x = np.linspace(0,2*np.pi)
-        tau = np.linspace(0, np.pi)
-        def f(x, tau):
-            return np.sin(x+tau)
-        interactive_plot(f, x=x, tau=tau)
-
-    with tuples::
-
-        x = np.linspace(0,2*np.pi)
-        def f(x, tau):
-            return np.sin(x+tau)
-        interactive_plot(f, x=x, tau=(0, np.pi, 1000))
-
-    """
-
-    ipympl = notebook_backend()
-    fig, ax = _gogogo_figure(ipympl, figsize)
-    use_ipywidgets = ipympl or force_ipywidgets
-    controls = interactive_plot_factory(
-        ax,
-        f,
-        x,
-        xlim,
-        ylim,
-        slider_format_string,
-        plot_kwargs,
-        title,
-        use_ipywidgets=use_ipywidgets,
-        **kwargs,
-    )
-    _gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
+    controls = gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
     return fig, ax, controls
 
 
@@ -566,6 +326,8 @@ def interactive_hist(
     slider_format_string=None,
     display=True,
     force_ipywidgets=False,
+    play_buttons=False,
+    play_button_pos="right",
     **kwargs,
 ):
     """
@@ -589,7 +351,7 @@ def interactive_hist(
         If tuple it will be used as the matplotlib figsize. If a number
         then it will be used to scale the current rcParams figsize
     ax : matplotlib axis, optional
-        if None a new figure and axis will be created
+        If None a new figure and axis will be created
     slider_format_string : None, string, or dict
         If None a default value of decimal points will be used. For ipywidgets this uses the new f-string formatting
         For matplotlib widgets you need to use `%` style formatting. A string will be used as the default
@@ -602,6 +364,12 @@ def interactive_hist(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
+    play_buttons : bool or dict, optional
+        Whether to attach an ipywidgets.Play widget to any sliders that get created.
+        If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
+        want to attach play buttons too.
+    play_button_pos : str, or dict, or list(str)
+        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
 
     returns
     -------
@@ -636,13 +404,13 @@ def interactive_hist(
         )
 
     ipympl = notebook_backend()
-    fig, ax = _gogogo_figure(ipympl, figsize=figsize, ax=ax)
+    fig, ax = gogogo_figure(ipympl, figsize=figsize, ax=ax)
     use_ipywidgets = ipympl or force_ipywidgets
 
     pc = PatchCollection([])
     ax.add_collection(pc, autolim=True)
 
-    slider_format_strings = _create_slider_format_dict(slider_format_string, use_ipywidgets)
+    slider_format_strings = create_slider_format_dict(slider_format_string, use_ipywidgets)
 
     # update plot
     def update(change, key, label):
@@ -662,11 +430,11 @@ def interactive_hist(
 
     # this line implicitly fills the params dict
     if use_ipywidgets:
-        sliders, slabels, controls = _kwargs_to_widget(
-            kwargs, params, update, slider_format_strings
+        (sliders, slabels, controls, play_buttons,) = kwargs_to_ipywidgets(
+            kwargs, params, update, slider_format_strings, play_buttons, play_button_pos
         )
     else:
-        controls = _kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
+        controls = kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
 
     new_x, new_y, new_patches = simple_hist(
         funcs[0](**params), density=density, bins=bins, weights=weights
@@ -675,7 +443,7 @@ def interactive_hist(
     ax.set_xlim(new_x)
     ax.set_ylim(new_y)
 
-    _gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
+    controls = gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
     return fig, ax, controls
 
 
@@ -698,6 +466,8 @@ def interactive_scatter(
     figsize=None,
     display=True,
     force_ipywidgets=False,
+    play_buttons=False,
+    play_button_pos="right",
     **kwargs,
 ):
     """
@@ -733,7 +503,7 @@ def interactive_scatter(
         If a tuple it will be passed to ax.set_ylim. Other options are same
         as xlim
     ax : matplotlib axis, optional
-        if None a new figure and axis will be created
+        If None a new figure and axis will be created
     slider_format_string : None, string, or dict
         If None a default value of decimal points will be used. For ipywidgets this uses the new f-string formatting
         For matplotlib widgets you need to use `%` style formatting. A string will be used as the default
@@ -752,6 +522,13 @@ def interactive_scatter(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
+    play_buttons : bool or dict or list(str), optional
+        Whether to attach an ipywidgets.Play widget to any sliders that get created.
+        If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
+        want to attach play buttons too. If a list of strings use the names of the parameters that
+        you want to have sliders
+    play_button_pos : str, or dict, or list(str)
+        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
 
     returns
     -------
@@ -800,9 +577,9 @@ def interactive_scatter(
 
     params = {}
     ipympl = notebook_backend()
-    fig, ax = _gogogo_figure(ipympl, figsize, ax)
+    fig, ax = gogogo_figure(ipympl, figsize, ax)
     use_ipywidgets = ipympl or force_ipywidgets
-    slider_format_strings = _create_slider_format_dict(slider_format_string, use_ipywidgets)
+    slider_format_strings = create_slider_format_dict(slider_format_string, use_ipywidgets)
     scats = []
     cache = {}
 
@@ -850,11 +627,11 @@ def interactive_scatter(
         fig.canvas.draw_idle()
 
     if use_ipywidgets:
-        sliders, slabels, controls = _kwargs_to_widget(
-            kwargs, params, update, slider_format_strings
+        sliders, slabels, controls, play_buttons = kwargs_to_ipywidgets(
+            kwargs, params, update, slider_format_strings, play_buttons, play_button_pos
         )
     else:
-        controls = _kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
+        controls = kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
     if title is not None:
         ax.set_title(title.format(**params))
 
@@ -913,10 +690,12 @@ def interactive_scatter(
             ax.set_title(title.format(**params))
 
     cache.clear()
-    _gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
+    controls = gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
     return fig, ax, controls
 
 
+# portions of this docstring were copied directly from the docsting
+# of `matplotlib.pyplot.imshow`
 def interactive_imshow(
     X,
     cmap=None,
@@ -939,6 +718,8 @@ def interactive_imshow(
     figsize=None,
     display=True,
     force_ipywidgets=False,
+    play_buttons=False,
+    play_button_pos="right",
     **kwargs,
 ):
     """
@@ -949,7 +730,7 @@ def interactive_imshow(
     X : function or image like
         If a function it must return an image-like object. See matplotlib.pyplot.imshow for the
         full set of valid options.
-    cmap : str or `~matplotlib.colors.Colormap`, default: :rc:`image.cmap`
+    cmap : str or `~matplotlib.colors.Colormap`
         The Colormap instance or registered colormap name used to map
         scalar data to colors. This parameter is ignored for RGB(A) data.
         forwarded to matplotlib
@@ -963,7 +744,7 @@ def interactive_imshow(
         If True rescale the colormap for every function update. Will not update
         if vmin and vmax are provided or if the returned image is RGB(A) like.
         forwarded to matplotlib
-    aspect : {'equal', 'auto'} or float, default: :rc:`image.aspect`
+    aspect : {'equal', 'auto'} or float
         forwarded to matplotlib
     interpolation : str
         forwarded to matplotlib
@@ -987,6 +768,13 @@ def interactive_imshow(
         If True ipywidgets will always be used, even if not using the ipympl backend.
         If False the function will try to detect if it is ok to use ipywidgets
         If ipywidgets are not used the function will fall back on matplotlib widgets
+    play_buttons : bool or dict or list(str), optional
+        Whether to attach an ipywidgets.Play widget to any sliders that get created.
+        If a boolean it will apply to all kwargs, if a dictionary you choose which sliders you
+        want to attach play buttons too. If a list of strings use the names of the parameters that
+        you want to have sliders
+    play_button_pos : str, or dict, or list(str)
+        'left' or 'right'. Whether to position the play widget(s) to the left or right of the slider(s)
 
     returns
     -------
@@ -997,9 +785,9 @@ def interactive_imshow(
 
     params = {}
     ipympl = notebook_backend()
-    fig, ax = _gogogo_figure(ipympl, figsize, ax)
+    fig, ax = gogogo_figure(ipympl, figsize, ax)
     use_ipywidgets = ipympl or force_ipywidgets
-    slider_format_strings = _create_slider_format_dict(slider_format_string, use_ipywidgets)
+    slider_format_strings = create_slider_format_dict(slider_format_string, use_ipywidgets)
 
     def update(change, label, key):
         if label:
@@ -1024,11 +812,11 @@ def interactive_imshow(
         fig.canvas.draw_idle()
 
     if use_ipywidgets:
-        sliders, slabels, controls = _kwargs_to_widget(
-            kwargs, params, update, slider_format_strings
+        sliders, slabels, controls, play_buttons = kwargs_to_ipywidgets(
+            kwargs, params, update, slider_format_strings, play_buttons, play_button_pos
         )
     else:
-        controls = _kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
+        controls = kwargs_to_mpl_widgets(kwargs, params, update, slider_format_strings)
 
     # make it once here so we can use the dims in update
     new_data = callable_else_value(X, params)
@@ -1053,6 +841,6 @@ def interactive_imshow(
     if title is not None:
         ax.set_title(title.format(**params))
 
-    _gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
+    controls = gogogo_display(ipympl, use_ipywidgets, display, controls, fig)
 
     return fig, ax, controls
